/*!
 * \file 
 * \brief Accel2 Click example
 * 
 * # Description
 * This application is three-axis accelerometer which embeds.
 *
 * The demo application is composed of two sections :
 * 
 * ## Application Init 
 * Initialization device. Check sensor ID and initialize Accel 2 click.
 * 
 * ## Application Task  
 * This is a example which demonstrates the use of Accel 2 click board.
   Measured coordinates (X,Y,Z) are being sent to the UART where you can track their changes.
 * 
 * \author MikroE Team
 *
 */
// ------------------------------------------------------------------- INCLUDES

#include "board.h"
#include "log.h"
#include "accel2.h"

// ------------------------------------------------------------------ VARIABLES

static accel2_t accel2;
static log_t logger;

// ------------------------------------------------------ APPLICATION FUNCTIONS

void application_init ( void )
{
    log_cfg_t log_cfg;
    accel2_cfg_t cfg;

    //  Logger initialization.

    log_cfg.level = LOG_LEVEL_DEBUG;
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info( &logger, "---- Application Init ----" );

    //  Click initialization.

    accel2_cfg_setup( &cfg );
    ACCEL2_MAP_MIKROBUS( cfg, MIKROBUS_1 );
    accel2_init( &accel2, &cfg );
}

void application_task ( void )
{
    int16_t value_x;
    int16_t value_y;
    int16_t value_z;
    uint8_t txt_x[ 15 ];
    uint8_t txt_y[ 15 ];
    uint8_t txt_z[ 15 ];

    value_x = accel2_read_xaxis( &accel2 );
    value_y = accel2_read_yaxis( &accel2 );
    value_z = accel2_read_zaxis( &accel2 );

    log_printf( &logger, "Axis X: %d\r\n", txt_x );
    log_printf( &logger, "Axis Y: %d\r\n", txt_y );
    log_printf( &logger, "Axis Z: %d\r\n", txt_z );
    log_printf( &logger, "-------------------------------" );

    Delay_ms( 5000 );
}

void main ( void )
{
    application_init( );

    for ( ; ; )
    {
        application_task( );
    }
}

// ------------------------------------------------------------------------ END
